## $Id: viewlets.py 15424 2019-05-24 10:13:52Z henrik $
##
## Copyright (C) 2015 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from waeup.kofa.interfaces import IKofaObject, academic_sessions_vocab
from waeup.kofa.browser.viewlets import (
    PrimaryNavTab, ManageActionButton, UpdateScoresActionButton,
    DownloadCSVFileActionButton, DownloadTicketOverviewActionButton)
from waeup.aaue.interfaces import MessageFactory as _

grok.context(IKofaObject)

class CheckAdmissionTab(PrimaryNavTab):
    """Check Admission tab in primary navigation.

    Display tab only for anonymous. 
    """
    grok.order(4)
    grok.require('waeup.Anonymous')
    tab_title = _(u'Check Admission')
    pnav = 2

    # Also zope.manager has role Anonymous.
    # To avoid displaying this tab, we have to check the principal id too.
    @property
    def link_target(self):
        if self.request.principal.id == 'zope.anybody':
            if 'alumni' in self.view.application_url():
                return
            return self.view.application_url('applicants') + '/checkstatus'
        return


class UpdatePreviousSessionScoresActionButton(UpdateScoresActionButton):
    """ 'Update scores' button in course.
    """
    grok.name('updateprevscores')
    target = 'edit_prev_scores'

    @property
    def target_url(self):
        return ''

        ## Button disabled on 30/11/2016
        #ca = grok.getSite()[
        #    'configuration'].current_academic_session
        #if not ca:
        #    return ''
        #return self.view.url(self.view.context, self.target)

    @property
    def text(self):
        ca = grok.getSite()[
            'configuration'].current_academic_session
        st = academic_sessions_vocab.getTerm(ca-1).title
        return _('Update session ${a} scores', mapping = {'a':st})


class CustomDownloadCSVFileActionButton(DownloadCSVFileActionButton):
    """ 'Download csv file' button for courses.
    """

    @property
    def target_url(self):
        if self.view.__name__ == 'edit_prev_scores':
            return self.view.url(self.view.context, 'download_prev_scores')
        return self.view.url(self.view.context, 'download_scores')


class CustomDownloadTicketOverviewActionButton(
    DownloadTicketOverviewActionButton):
    """ 'Download ticket overview' button for courses.
    """

    @property
    def target_url(self):
        if self.view.__name__ == 'edit_prev_scores':
            return ''
        return self.view.url(self.view.context, 'coursetickets.pdf')

